function fdtd_sw(mdl,exc,out,sw,nmax,n_disp)
% mdl: model
% exc: excitation source
% out: output
% sw:  Schwarzschild parameters
% nmax: the maximum time step
% n_disp: the time step interval for display in command window
%
% mdl:   1  1 struct: model
%   mdl.Nmedium 1  1  Number of medium types except air and PEC. If Nmedium > 0,there should be two fields epsr and mur:
%   mdl.epsr    Nmedium  1 Relative permittivity
%   mdl.mur     Nmedium  1 Relative permeability
%   mdl.NXi     1  1 Number of mesh node in x direction
%   mdl.NYi     1  1 Number of mesh node in y direction
%   mdl.NZi     1  1 Number of mesh node in z direction
%   mdl.x       NXi  1  Local x coordinates of mesh node (m), the global coordinates are sw.X0+[mdl.x,mdl.y,mdl.z]
%   mdl.y       NYi  1  Local y coordinates of mesh node
%   mdl.z       NZi  1  Local z coordinates of mesh node
%   mdl.tEx     NXi-1  NYi    NZi   Medium type in Ex location:  PEC=-1, Air=0, medium=1~Nmedium
%   mdl.tEy     NXi    NYi-1  NZi   Medium type in Ey location
%   mdl.tEz     NXi    NYi    NZi-1 Medium type in Ez location
%   mdl.tHx     NXi    NYi-1  NZi-1 Medium type in Hx location
%   mdl.tHy     NXi-1  NYi    NZi-1 Medium type in Hy location
%   mdl.tHz     NXi-1  NYi-1  NZi   Medium type in Hz location
%
% exc:   1  1 struct: excitation source
%   exc.f_dipole  1  1 Is there dipole excitation? If f_dipole is true, there should be the field 'dipole':
%   exc.dipole    1  1 struct : Dipole excitation in z direction, and it occupies one grid
%       exc.dipole.co     3  1 Coordinates
%       exc.dipole.wave   1  1 struct :Waveform
%   exc.f_v  1  1 Is there voltage excitation? If f_v is true, there should be the field 'v':
%   exc.v    1  1 struct: Voltage excitation
%       exc.v.dir    1  1 char: Direction =='X','Y','Z'
%       exc.v.co     4  1 Coordinates,If dir='X', co(1:2) are x coordinates, co(3) is y coordinate, co(4) is z coordinate
%                                       If dir='Y', co(1) is x coordinate, co(2:3) are y coordinates, co(4) is z coordinate
%                                       If dir='Z', co(1) is x coordinate, co(2) is y coordinate, co(3:4) are z coordinates
%       exc.v.type   1  1 char: 'S' or 'H'
%       exc.v.wave   1  1 struct :Waveform
%
%           wave     1  1 struct: Waveform
%               wave.type	string: Type of waveform: 'SINE', 'GAUSS', 'DIFFGAUSS' or 'MODGAUSS'
%               wave.A      1  1 Amplitude
%               if type='SINE',there should be :
%               wave.F      1  1 Frequency(Hz)
%               if type='GAUSS' or 'DIFFGAUSS' or 'MODGAUSS',there should be :
%               wave.BW     1  1 Bandwidth(Hz)
%               if type='MODGAUSS',there should be :
%               wave.F0     1  1 Central frequency(Hz)
%
% out:   1  1 struct: Output
%   out.nv     1  1  Number of output voltage, if nv > 0, there should be the field 'v':
%   out.v      1  nv struct: output voltage
%       out.v.dir     1  1 char Direction='X' or 'Y' or 'Z'
%       out.v.co      4  1 Coordinates, the same as exc.v.co
%       out.v.fname   string: File name of the output file
%   out.np     1  1  Number of the output plane, if np > 0, there should be the field 'plane':
%   out.plane  1  np struct:  output electric distribution in a plane
%       out.plane.p      char:  'x' or 'y' or 'z'
%       out.plane.co     1  1 Coordinate
%       out.plane.nt     n  1 Time steps
%       out.plane.e      string: 'Ex' or 'Ey' or 'Ez'. Output e in plane p=co at time step nt.
%       out.plane.fname  string: File name of the output file
%
% sw:   1  1 struct: Schwarzschild parameters
%   sw.Rs  1  1: Schwarzschild Radius
%   sw.X0  3  1: The global coordinates of origin of local coordinates system
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%n_disp=50;
% if(nargin<5)
%     chk=false();
% end
% if(chk)
%     checkin(mdl,exc,out);
% end
%
disp('FDTD initializing ...');
[mdl,exc,out,v]=init(mdl,exc,out,sw);
n0=0;
%nmax=input('input max time step : ');
disp('FDTD start ...');
while(1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    for n=n0:nmax-1
        if(mod(n,n_disp)==0)
            disp(['step ' num2str(n) '/' num2str(nmax)]);
        end
        v=update_e_sw(mdl,sw,v); % n*dx0
        [exc,v]=source_add(mdl,exc,v,n);
        v=update_h_sw(mdl,sw,v); % (n+0.5)*dx0
%         if(exc.f_pw)
%             [exc.pw,v]=pw_subtract(mdl,exc.pw,v);
%         end
%         for i=1:out.nfar
%             out.far(i)=farfield(mdl,out.far(i),v);
%         end
        output(mdl,out,v,n);
    end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%     [n0,nmax,fe]=enq(n0,nmax);
%     if(fe)
         break;
%     end
end
out_post(out);
disp('FDTD END.');
end